@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 #
-# Copyright (C) 2005, 2008 Nicolas Burrus
+# Copyright (C) 2005, 2008, 2009 Nicolas Burrus
 # This file is part of Tidydoc.
 #
 # Tidydoc is free software; you can redistribute it and/or modify
@@ -132,54 +132,7 @@ Visibility: public
 
 Language: english
 
-Bibtex type:
-%% inproceedings
-%% article
-%% misc
-%% inbook
-%% book
-%% phdthesis
-%% techreport
-%% incollection
-
-Bibtex fields:
-%%%% In Proceedings
-%% booktitle = {}
-%% volume = {}
-%% number = {}
-%% pages = {--}
-
-%%%% Article
-%% journal = {}
-%% volume = {}
-%% number = {}
-%% pages = {--}
-
-%%%% Misc
-%% text = {}
-
-%%%% In Book
-%% chapter = {}
-%% publisher = {}
-%% pages = {--}
-
-%%%% Book
-%% publisher = {}
-
-%%%% Phd Thesis
-%% school = {}
-%% month = {}
-
-%%%% Technical Report
-%% institution = {}
-
-%%%% In Collection
-%% booktitle = {}
-%% editor = {}
-%% publisher = {}
-%% address = {}
-%% pages = {--}
-%% month = {}
+Bibtex:
 
 Comment:
 
